/*****************************************************************************
* FileName     : moia_define.h                                               *
* SystemName   : ADTec-Moia                                                  *
* Version      : 3.0                                                         *
* ProgramName  : 宏定义头文件                                                *
* OS           : AIX 5.0.0                                                   *
* DB           : DB2 SDK 8.1.0                                               *
*              : ORACLE 9i                                                   *
*              : INFORMIX IDS 2000                                           *
* History      :                                                             *
* YYYY/MM/DD Position     Author        Description                          *
* ---------------------------------------------------------------------      *
* 2006/05/23 Shanghai     Tangsui       Created                              *
*****************************************************************************/

#ifndef   MOIADEFINE_H
#define   MOIADEFINE_H

/******************** 数据库操作结果处理类 ************************/
#ifndef   SQLCODE 
#define   SQLCODE              (sqlca.sqlcode)
#endif

#ifndef   SQLISM
#define   SQLISM               (sqlca.sqlerrd[1])
#endif

#ifndef   SQLREC
#define   SQLREC               (sqlca.sqlerrd[2])
#endif

#ifndef   SQLSUCC
#define   SQLSUCC              (0)
#endif

#ifndef   SQLNOTFOUND

#ifdef ORACLE
#define   SQLNOTFOUND          (1403)
#define   SQLNULL              (-1405)
#define   SQLMULTI             (-1)
#define   SQLBUSY              (-54)
#define   SQLSELMUCH           (1427)
#elif defined DB2
#define   SQLNOTFOUND          (100)
#define   SQLNULL              (100) /* db2 暂时没有空字段错误*/
#define   SQLMULTI             (-803)
#define   SQLBUSY              (100) /* db2 没有nowait返回码 */
#define   SQLWORK              (-880)
#define   SQLSELMUCH           (-811)
#elif defined PG
#define   SQLNOTFOUND          (100)
#define   SQLNULL              (100) 
#define   SQLMULTI             (-403)
#define   SQLBUSY              (100)
#define   SQLSELMUCH           (-203)
#elif defined MYSQL_M
#define   SQLMULTI             (1062) 
#endif

#endif

#define   UMASK                022

#define   TRACE_OFF            100            

#define   MOIA_DATE_FMT        "YYYYMMDD"   /* MOIA 参数表中日期字段的格式 */
#define   DATE_LEN             8            
#define   TIME_LEN             6            

#define   LIC_DATE_FMT         "YYYY/MM/DD"  /* LICENSE中日期字段的格式 */
#define   LIC_LEN             8            

#define   QUEUE_KEEP_DAYS      10    /* 队列中成功的子任务保留天数 */
#define   MD5KEYLEN            16    /* MD5加密长度定义， 实际长度为改值两倍 */

#define INIT_STAT_STR( col )  init_stat_str( col, sizeof( col ) );

#define MOIA_SQL_CHECK( msg ) \
if( SQLCODE != SQLSUCC && SQLCODE != SQLNOTFOUND && SQLCODE != SQLNULL ) { \
    db_log( __FILE__,__LINE__,"%s", msg );\
    if( G_has_trans == _YES_ ) db_rollback_work(); \
    return _FAIL_;\
}

/* close by Tangsui on 20070331
#define MOIA_REC_CHECK( msg ) \
if( SQLREC != 1 ) { \
    db_log( __FILE__,__LINE__,"%s", msg );\
    if( G_has_trans == _YES_ ) db_rollback_work(); \
    return _FAIL_;\
}
*/

#define MOIA_FUNC_ERR( func_name ) { \
    err_log( __FILE__,__LINE__,"%s() failed!", func_name ); \
    if( G_has_trans == _YES_ ) db_rollback_work(); \
    return _FAIL_; \
}

#define OS_FUNC_ERR( func_name ) { \
    err_log( __FILE__,__LINE__,"%s() failed! errno:[%d]", func_name, errno ); \
    if( G_has_trans == _YES_ ) db_rollback_work(); \
    return _FAIL_; \
}

#define MOIA_ERR_LOG( fmt, msg )  err_log( __FILE__, __LINE__, fmt, msg );

#define ZOOTIMEOUT 300
#define ZOOCONNTXT "Hello zookeeper!"



/******************** 函数返回结果 ************************/
#define   _SUCC_               0   /* 成功  */
#define   _FAIL_               -1  /* 失败  */
#define   _NORUN_              -2  /* 未执行,用于参数不匹配时 */
#define   _NOT_EXIST           -3  /* 文件/路径不存在         */
#define   _NOT_DIR             -4  /* 不是合法路径            */
#define   _NOT_FILE            -5  /* 不是合法文件名          */
#define   _NO_NET_             -6  /* 无法建立网络连接        */
#define   _NET_ERR             -7  /* 网络传输故障            */
#define   JOB_AT_FAIL          -8  /* 作业数据稽核失败        */
#define   OTHER_ABNOR          -9  /* 其它异常返回值          */

#define   _NORC_               1   /* 无记录,用于数据库/文件读取操作函数 */
#define   _GONO_               2   /* 检查不通过,记日志,不报错 */
#define   _PTSC_               3   /* 处理成功,存在reject记录  */
#define   _WARN_               4   /* 处理成功,存在警告 */
#define   _NEVER_              5   /* 返回结果永不满足 */

#define   _YES_               1    /* 是/有/存在  /开启/真  */
#define   _NO_                0    /* 否/无/不存在/关闭/假  */
#define   _INIT_              -1   /* 初始状态/第一次/无初值 */
#define   _LOCK_              -3   /* 锁定标志 */

#define   _YES_C_            '1'  /* 是/有/存在  /开启/真  */
#define   _NO_C_             '0'  /* 否/无/不存在/关闭/假  */
#define   _IGN_C_            '9'  /* 否/无/不存在/关闭/假  */

#define   AVB_REC_INVALID    '9'   /* avb_flag: 记录禁用 */
#define   AVB_REC_VALID      '1'   /* avb_flag: 记录有效 */

#define   INPUT_CNT_MAX       10000              /* 输入计数器登记条数 */
#define   UPD_INPUT_CNT       "upd_input_cnt"    /* 修改计数器的可执行程序名*/


/******************** 创建目录的权限 **********************/
#define  DIR_MODE   S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH

/*-----------------------  定义 日历种类 的宏 -*/
#define        CAL_RANDOM   '0'          /*不定期*/
#define        CAL_DATE     '1'          /*日期日历*/
#define        CAL_WEEK     '2'          /*周日历*/

#define        CAL_NOT_DO   '0'          /*指定的日历不执行,未指定的日期都执行*/
#define        CAL_NEED_DO  '1'          /*指定的日历执行*/


/*-----------------------  定义调度计划类型 的宏 */
/* pln_info.plan_type */
#define        DAILY_PLAN        '1'      /* 日常计划  */
#define        MANUAL_PLAN       '2'      /* 手工计划  */
#define        CYCLE_PLAN        '3'      /* 循环计划  */


/*-----------------------  定义 依赖/事件状态 的宏 -*/
/* event_stat */
#define        EVT_INIT           1001  /* 初始化           */
#define        EVT_READY          8001  /* 已就绪/已满足    */
#define        EVT_NEVER          2001  /* 永不满足         */
#define        EVT_EXPIRE         5001  /* 已失效           */
/* evt_glob_flag */
/* evt_flow_flag */
#define        EVT_FLAG_NO             '0'  /* 事件未满足           */
#define        EVT_FLAG_YES            '1'  /* 事件已满足           */
#define        EVT_FLAG_NEVER          '9'  /* 事件永不满足         */

/* --------------------- 定义 DS工程作业参数检查状态 的宏 ----*/
#define        DS_CHK_INIT      -1  /* 尚未进行检查                    */
#define        DS_CHK_SUCC       0  /* 正常可用                        */
#define        DS_CHK_FAIL       1  /* 检查不通过,不可用               */
#define        DS_CHK_DEAL       2  /* 正在检查                        */

/* --------------------- 定义 日志打印级别 的宏 ----*/
#define        MLOG_DEBUG        -9  /* debug 类型日志 */
#define        MLOG_INFO         0  /* 基础类型日志 */
#define        MLOG_WARN         1  /* 警告类型日志 */
#define        MLOG_ERR          2  /* 错误类型日志 */
#define        MLOG_FATAL        3  /* 严重错误类型日志 */

/********************** 物理作业类型 **********************************/
/* func_type */
/* deal_flag */
#define        DL_DSEE_JOB     '2'  /* DSEE类任务 */
#define        DL_DSSE_JOB     '3'  /* DSSE类任务 */
#define        DL_DBSJ_JOB     '5'  /* 存储过程作业 */
#define        DL_CMDJ_JOB     '9'  /* 普通任务 */

#define        DL_PERL_JOB     'a'  /* PERL作业 */
#define        DL_OSHELL_JOB   'b'  /* OSHELL作业 */
#define        DL_PYTHON_JOB   'c'  /* PYTHON作业 */
#define        DL_JAVA_JOB     'd'  /* JAVA作业 */
#define        DL_SCALA_JOB    'e'  /* SCALA作业 */
#define        DL_WEBSRV_JOB   'f'  /* web service作业 */
#define        DL_DATASRV_JOB  'g'  /* data service作业 */
#define        DL_KETTLE_JOB   'h'  /* kettle 作业 */
#define        DL_INFORM_JOB   'i'  /* informatica 作业 */

#define        DL_PLUG_JOB     'z'  /* 插件作业 */

/* pnd_jobstat.res_type */
#define        DSEE_C_RES   '1'  /* DL_DSEE_JOB在ETL Client节点所占资源 */
#define        DSEE_S_RES   '2'  /* DL_DSEE_JOB在ETL Server节点所占资源 */
#define        DSSE_S_RES   '3'  /* DL_DSSE_JOB在ETL Server节点所占资源 */
#define        CMDJ_S_RES   '4'  /* DL_COM_JOB 在ETL Server节点所占资源 */
#define        DBSJ_S_RES   '5'  /* DL_DBS_JOB 在ETL Server节点所占资源 */
#define        DBSJ_C_RES   '6'  /* DL_DBS_JOB 在数据库节点所占资源 */

#define        DSEE_MAST_RES   0  /* DL_DSEE_JOB的指挥服务所占的资源*/
#define        DBSJ_MAST_RES   0  /* DBS作业的指挥服务所占的资源*/


/*-----------------------  定义 license控制方式的宏 -*/
/* control_way */
#define        CTRL_BY_CPU        '0'  /* CPU数量   */
#define        CTRL_BY_PROC       '1'  /* 进程数    */
#define        CTRL_BY_JOB        '2'  /* JOB数     */

/*-----------------------  定义 物理节点状态 的宏 -*/
/* pnode_stat */
#define        PNODE_NORMAL      0  /* 正常     */
#define        PNODE_DEAD        1  /* 节点死亡 */
#define        PNODE_NETERR      2  /* 网络断开 */
#define        MAYBE_NETERR      3  /* 网络断开 */
#define        PNODE_SOFTERR     4  /* 软件故障 */
#define        MAYBE_SOFTERR     5  /* 软件故障 */
#define        PNODE_UNUSED      6  /* 未启用   */

/* 以下三种状态在资源分配中临时使用宏 */
#define        PNODE_CPU_LACK    7  /* CPU已到阀值  */
#define        PNODE_MEM_LACK    8  /* 内存已到阀值 */
#define        PNODE_RESMD       9  /* 资源以修改 */

/*-----------------------  定义 资源状态状态 的宏 -*/
/* job_cnode.res_stat */
/* job_pnode.res_stat */
#define        RES_OK       0  /* 正常,够用         */
#define        RES_UPLMT    1  /* 资源到阀值        */
#define        JOB_UPLMT    2  /* 作业数阀值        */
#define        RES_LACK     3  /* 资源不足          */
#define        STAT_ABNOR   4  /* 节点状态异常      */
#define        INDEP_LACK   5  /* 节点物理资源不足      */

/* pnd_resstat.res_stat */ 
#define        HW_RES_OK      '0'  /* 硬件资源充足 */
#define        HW_CPU_LACK    '1'  /* CPU已到阀值  */
#define        HW_MEM_LACK    '2'  /* 内存已到阀值 */


/* param_type 参数类型 */
#define       PARAM_NUMBER       '0'
#define       PARAM_DATE         '1'
#define       PARAM_STRING       '2'
#define       PARAM_ENCSTR       '3'
#define       PARAM_ENV          '4'

/* plug_type 插件类型 */
#define       ASYNC_PLUG         '0'   /* 异步插件 */
#define       SYNC_PLUG          '1'   /* 同步插件 */

/* 插件程序命令类型，插件程序参数类型 */
#define       EXEC_PLUG          '1'
#define       STAT_PLUG          '2'
#define       LOG_PLUG           '3'
#define       STOP_PLUG          '4'


/* shift_rule[0] */
#define        SHIFT_ONLY_ONCE   '1'  /* 一个自然日只能日切一次 */
#define        SHIFT_NO_LIMIT    '2'  /* 无日切间隔控制         */

/* 流程嵌套层级 */
#define        MAXLEVEL       5 

/* 同级最大流程数 */
#define        MAXSEQ         10000

/* tragger_type */
#define        TRIG_SUCC      '1'   /* 对象成功触发事件 */
#define        TRIG_FAIL      '2'   /* 对象失败触发事件 */
#define        TRIG_COMP      '3'   /* 对象完成触发事件 */
#define        TRIG_WARN      '4'   /* 对象超时触发事件 */


/*
 * 调度对象类型
 */
/* obj_type */
#define       PLAN            '1'       /* 计划  */
#define       TASK            '2'       /* 任务  */
#define       SEQ             '3'       /* 流程  */
#define       JOB             '4'       /* 作业  */

/* 总计状态
 * pln_stat.plan_stat 
 * tak_stat.task_stat 
 * seq_stat.seq_stat
 * job_stat.job_stat 
 */

#define       _WAIT_STAT_          1001    /* 待处理     */
#define       _DEAL_STAT_          4001    /* 正在处理   */
#define       _SUCC_STAT_          8001    /* 成功       */
#define       _FAIL_STAT_          5001    /* 失败       */

/* 细分状态 
 * pln_stat.child_stat 
 * tak_stat.child_stat 
 * seq_stat.child_stat
 * job_stat.child_stat 
 */

/* 过渡状态类 */
#define        _WAIT_SCAN_     1001   /* 待处理             */
#define        _WAIT_RES_      1002   /* 待分配             */
#define        _WAIT_DEAL_     1003   /* 代执行             */

/* 正在处理类 */
#define        _DEAL_NOR_      4001  /* 正在处理            */
#define        _DEAL_REDO_     4002  /* 正在处理 (重做)     */
#define        _DEAL_WARN_     4003  /* 正在处理 (警告)     */
#define        _DEAL_ERR_      4004  /* 正在处理 (有失败)   */
#define        _DEAL_HALT_     4005  /* 正在处理 (中断中)   */
#define        _DEAL_SUB_WARN_ 4006  /* 正在处理 (下级警告) */

/* 处理失败类 */
#define        _SUCC_NOR_      8001   /* 成功              */
#define        _SUCC_IGN_      8002   /* 成功 (忽略)       */
#define        _SUCC_WARN_     8003   /* 成功 (警告)       */
#define        _SUCC_CTRL_     8004   /* 成功 (非执行分支) */
#define        _SUCC_INCAL_    8005   /* 成功 (非执行日)   */

/* 处理成功类 */
#define        _FAIL_NOR_      5001   /* 处理失败              */
#define        _FAIL_HALT_     5002   /* 处理失败 (中断)       */
#define        _FAIL_BESP_     5003   /* 处理失败 (前脚本失败) */
#define        _FAIL_AFSP_     5004   /* 处理失败 (后脚本失败) */
#define        _FAIL_LOSE_     5005   /* 处理失败 (进程丢失)   */
#define        _FAIL_INIT_     5006   /* 处理失败 (初始化失败) */

/*-----------------------  定义 处理队列状态 的宏 -*/
/* que_deal.deal_stat */
#define        DL_IDLE        0     /* 等待处理 */
#define        DL_OUTQUE      1     /* 取出队列 */
#define        DL_DEAL        2     /* 正在处理 */
#define        DL_SEND        3     /* 作业发送 */

/*-----------------------  定义 文件类型 的宏 -*/
#define        FIXED_FILE     0 /* 定长文件 */
#define        DELI_FILE      1 /* 不定长文件,分隔符文件,变长文件 */

/******************** 数据库操作种类定义 ************************/
#define        DB_SELECT       0   /* 查找 */
#define        DB_DELETE       1   /* 删除 */
#define        DB_UPDATE       2   /* 修改 */
#define        DB_INSERT       3   /* 插入 */
#define        UPD_BY_TM       4   /* 带上时间戳修改,避免session覆盖 */

/******************** 数据库操作索引编号 ************************/
#define        DB_PRIMKEY      0   /* 用主键作为条件 */
#define        DB_UNIQIDX1     1   /* 用第一条唯一索引作为条件 */
#define        DB_UNIQIDX2     2   /* 用第二条唯一索引作为条件 */
#define        DB_UNIQIDX3     3   /* 用第三条唯一索引作为条件 */
#define        DB_UNIQIDX4     4   /* 用第四条唯一索引作为条件 */
#define        DB_UNIQIDX5     5   /* 用第五条唯一索引作为条件 */
#define        DB_UNIQIDX6     6   /* 用第六条唯一索引作为条件 */
#define        DB_UNIQIDX7     7   /* 用第七条唯一索引作为条件 */

/******************** 节点服务类型***************************/
/*  .srv_pnode */
#define        SRV_SLAVER        0  /* 从节点服务 */
#define        SRV_MASTER        1  /* 主节点服务 */

/******************** 服务状态定义 ****************************/
/*  .proc_stat  */
#define        SRV_INIT        0  /* 初始 */
#define        SRV_BUSY        1  /* 忙碌 */
#define        SRV_IDLE        2  /* 空闲 */
#define        SRV_NEW_REC     3  /* 有新记录,需扫描 */
#define        SRV_RESTART     4  /* 进程为重启退出 */
#define        SRV_STOP        8  /* 未运行 */
#define        SRV_EXIT        9  /* 退出 */
#define        SRV_ABNOR       99 /* 异常 */

/******************** 作业初始化域类型 ******************************/
#define        NODE_DOMAIN        '1'  /* 继承节点上的域 */
#define         JOB_DOMAIN        '0'  /* 作业自己初始化域 */

/********************* 调度对象状态锁定标志 *******************/
#define          LOCK          '1'    /* 锁定   */
#define        UNLOCK          '0'    /* 不锁定 */

/********************* 参数类型 *********************/
/*Param_type*/
#define            CONST_VAR     '0'     /* 常量参数     */
#define             DATE_VAR     '1'     /* 日期型参数   */
#define           STRING_VAR     '2'     /* 字符串型参数 */
#define         STRING_E_VAR     '3'     /* 字符串型参数 加密型*/

/********************* 物理作业类型 *********************/
/* JOB_type */
#define          FUNC_JOB        '0'      /* 调度类作业 */
#define          FUNC_CTRL       '1'      /* 控件类作业 */

/********************* 作业返回值标示 *********************/
/* ret_flag */
#define          RET_SUCC        '0'      /* 返回成功 */
#define          RET_FAIL        '1'      /* 返回失败 */
#define          RET_WARN        '2'      /* 成功有警告 */
#define          RET_DEAL        '3'      /* 正在处理 */

/********************* 特殊作业返回值 *********************/
/* ret_code */
#define          LOSE_FAIL      77777777       /* 进程丢失返回值 */
#define          PRSP_FAIL      88888888       /* 前处理失败返回值 */
#define          AFSP_FAIL      99999999       /* 后处理失败返回值 */

/********************* 作业返回值标示 *********************/
/* rela_flag */
#define          RELA_STAT        '0'      /* 依赖状态 */
#define          RELA_CODE        '1'      /* 依赖返回值 */

/********************** 加密标志 *****************************/
/* var_flag */
#define          ENC_NO         '1'      /* 未加密 */
#define          ENC_YES        '2'      /* 加密 */

/******************** license状态定义 ****************************/
#define        LIC_NORMAL         0  /* 正常         */
#define        LIC_EXPIRED        -1 /* 过期         */
#define        LIC_JOBLIMIT       -2 /* 作业数超过限制 */
#define        LIC_PNODELIMIT     -3 /* 节点数超过限制 */
#define        LIC_INVALID        -9 /* 非法License  */


/* slave ctrl运行状态 */
#define    CTRL_RUNING  "1"
#define    CTRL_ABORT   "0"
#define    CTRL_STOP    "2"


#define SUCC_FLAG   "1"    /* 命令执行成功 */
#define FAIL_FLAG   "0"    /* 命令执行失败 */
#define KEEP_FLAG   "2"    /* 继续接收标志 */

/* MOIA 各个服务名对应的宏 */
#define MJOB                "mjob"
#define MOIALSNR            "MoiaLsnr"
#define LSNRSTOP            "lsnrstop"
#define MTASKSCAN           "MTaskScan"
#define MTASKCTRL           "MTaskCtrl"
#define MCTRLSRV            "MCtrlSrv"
#define MCTRLAGT            "MCtrlAgt"
#define MTASKDEAL           "MTaskDeal"
#define MTASKRES            "MTaskRes"
#define MRECVCHK            "MRecvChk"
#define MREFERCHK           "MReferChk"
#define MCMDSRV             "MCmdSrv"
#define MCLMAGT             "MClmAgt"
#define MCLMSRV             "MClmSrv"
#define MLICMNG             "MLicMng"
#define MSRVADM             "MSrvAdm"
#define MCMDCHK             "MCmdChk"
#define MPARACHK            "MParaChk"
#define MDATADEAL           "MDataDeal"
#define MTIMESCAN           "MTimeScan"
#define MFILESCAN           "MFileScan"
#define MLOGCLR             "MLogClr"
#define MOIAVER             "MoiaVer"


#define PAUSE           '1'          /* 任务暂停标志 */

#define TMOUT_SEC       5           /* time out */
#define PROC_SLEEP      1           /* time out */

#define SRV_EXIT_WAIT_SEC   10          /* 终止服务的最长等待时间（近似值，实际时间会略长于此时间） */
#define SRV_START_WAIT_SEC  5           /* 启动服务的最长等待时间（近似值，实际时间会略长于此时间） */

#define SND_SLEEP_TIME (60*5)           /* send sleep time */

#define MINI_JOB_SIZE  (50*1000*1000) /* 判为小任务的输入实例大小界限 50M */

#define MOIA_LIC_CFG        "lic_cfg.txt"

/******************* 日志文件名定义 ************************/
#define   MOIAJOBLOG   "jobrun.log"
#define   MOIALICLOG   ".mlic.log"
#define   MOIAERRLOG   "moia.err"
#define   MOIATRCLOG   "moia.trc"
#define   MOIADBGLOG   "moia.log"
#define   DBERRLOG     "dberr.log"

/**************** MOIA作业预设返回值种类 *******************/
/* job_fcrc.fcrc_type,s_job_fcrc.fcrc_type           */
#define   FCRC_SINGLE       1
#define   FCRC_AREA         2
#define   FCRC_OTHER        3



/******************** 变量长度定义类 ************************/
#define   DBNAME_LEN           32             /* 数据库名长度       */
#define   DBUSER_LEN           20             /* 数据库用户长度     */
#define   DBUSRPWD_LEN         32             /* 数据库用户口令长度 */
#define   TABNAME_LEN          128            /* 数据库表口令长度 */
#define   PATHLEN              256            /* 文件存放路径长度   */
#define   FILENAME_LEN         256            /* 不带路径的纯文件名长度   */
#define   FULLPATHLEN          512            /* 带全路径文件名长度 */
#define   ORGLEN               6              /* 机构/分行号长度    */


/******************* 错误码定义 ************************/
/* 第一位： 作业阶段 */
#define   SCAN_STEP     '1'   /*   作业扫描失败         */
#define   RESC_STEP     '2'   /*   资源分配失败         */
#define   CTRL_STEP     '3'   /*   作业调度失败         */
#define   STAT_INIT     '4'   /*   作业初始状态修改失败 */
#define   OBJT_INIT     '5'   /*   作业对象初始化失败   */
#define   PARA_INIT     '6'   /*   作业参数初始化失败   */
#define   EXEC_STEP     '7'   /*   作业执行失败         */
#define   STAT_OVER     '8'   /*   作业结束状态修改失败 */


#define CON_TIMES          1.5   /* 作业运行时间超过最大耗时50%  */
#define WAR_TIMES          3     /* 作业运行时间超过最大耗时300% */


#define MOIAENV            "moia.env"    /* Moia环境变量配置文件 */

#define  ACT_LIST_PNODE  0   
#define  ACT_START_SRV  1
#define  ACT_STOP_SRV   2


/* dbs_type */
#define DB_KIND_ORA         '1'   /* ORACLE   */
#define DB_KIND_DB2         '2'   /* DB2      */
#define DB_KIND_INF         '3'   /* INFORMIX */
#define DB_KIND_HANA        '4'   /* HANA */
#define DB_KIND_DS          '5'   /* DATASERVICE */
#define DB_KIND_IFM         '6'   /* INFORMATIC */
#define DB_KIND_PG          '7'   /* PostGreSQL */
#define DB_KIND_MYSQL       '8'   /* MYSQL */
#define DB_KIND_GBASE       '9'   /* GBASE */

/* db_type int */
#define DB_TYPE_ORA         1   /* ORACLE   */
#define DB_TYPE_DB2         2   /* DB2      */
#define DB_TYPE_INF         3   /* INFORMIX */
#define DB_TYPE_HANA        4   /* HANA */
#define DB_TYPE_DS          5   /* DATASERVICE */
#define DB_TYPE_IFM         6   /* INFORMATIC */
#define DB_TYPE_PG          7   /* PostGreSQL */
#define DB_TYPE_MYSQL       8   /* MYSLQ */
#define DB_TYPE_GBASE       9   /* GBASE */


/* col_type 状态字段类型 */
#define SQL_INTEGER          1  /* 整型       */
#define SQL_STRING           2  /* 字符型     */

/***************** MCtrlAgt中对作业的类型定义 **************************/
/* job_type */
#define        CTRL_DSEE_JOB     1  /* DSEE类任务 */
#define        CTRL_DSSE_JOB     2  /* DSSE类任务 */
#define        CTRL_CMDJ_JOB     3  /* 普通任务 */
#define        CTRL_DBSJ_JOB     4  /* 存储过程作业 */

/***************** DS作业执行方式 **************************/
/* exec_type */
#define        DSJ_API     1  /* API方式 */
#define        DSJ_CMD     2  /* command方式 */

/****************** 消息队列类型 *****************/
#define        MSGKEY      8669 
#define        MSG_SEED    'q'
#define        MSGTYPE     1  

/***************** 下发报文分隔符 ***************/
#define       MSG_SPLIT               '\001'  /* | */
#define       PARAM_SPLIT             '\002'  /* : */
#define       PARAM_EQUAL             '\003'  /* = */

/***************** 状态描述信息 ****************/
#define  MSG_WAIT_FLOW    "#流程依赖不满足#"
#define  MSG_WAIT_EVENT   "#事件依赖不满足#"
#define  MSG_WAIT_TIME    "#时间点未到#"
#define  MSG_RES_LACK     "#资源不足#"
#define  MSG_PNODE_LACK   "#无可用节点#"

#define DEF_INST_NUM "000000000000000000"

#define IPCMODE    0600

/********************* 异常类型 ERR_TYPE *************************/
#define  ERR_DISK           '2'          /* 磁盘空间不足 */
#define  ERR_SERVICE        '3'         /* 服务进程异常 */

/********************* 异常级别 ERR_LEVEL *************************/
#define  ERROR          '1'          /* 错误 */
#define  WARN           '2'          /* 警告 */

#define INDEP_OK    0
#define INDEP_GLOBAL 1
#define INDEP_PNODE  2

/** que type **/
#define QUE_WAIT 1
#define QUE_RES  2
#define QUE_DEAL 3

/* demo id */
#define DEMO_ID   "00000000000000000000000000000000"
#define DEMO_INST "00000000000000000000"

/* G_RES_QUE_FLAG */
#define _QUE_DELETE_ 0
#define _QUE_UPDATE_ 1

#ifdef __x86_64__
__asm__(".symver memcpy,memcpy@GLIBC_2.2.5");
#endif

#endif
