#!/bin/bash

# Desc:
# 1. 参数按照顺序传入, 根据命令使用不同参数
# 2. 功能: 调度Informatica作业执行; 获取workflow日志; 获取失败session日志
# 3. 传入参数: 
#    服务名      : 读取数据源配置
#    域名        : 读取数据源配置
#    用户名      : 读取数据源配置
#    密码        : 读取数据源配置
#    工作流文件夹: 作业参数传入
#    工作流名称  : 作业参数传入
#    参数文件    : 作业参数传入

# 数据源参数
domain_service=$1
domain_name=$2
domain_user=$3
domain_password=$4
# 作业参数
folder_name=$5
workflow_name=$6
paramfile=$7

# 日志函数
Log()
{
    currTime=`date +"%Y%m%d_%H:%M:%S"`
    echo "${currTime} $*"
}
echo

Log "参数检查:"
echo
paramFlag="Y"
if [ "X${domain_service}" == "X" ];then
    Log "[Error] 集成服务名称为空"
    paramFlag="N"
fi
if [ "X${domain_name}" == "X" ];then
    Log "[Error] 域名为空"
    paramFlag="N"
fi
if [ "X${domain_user}" == "X" ];then
    Log "[Error] 用户名为空"
    paramFlag="N"
fi
if [ "X${domain_password}" == "X" ];then
    Log "[Error] 密码为空"
    paramFlag="N"
fi
if [ "X${folder_name}" == "X" ];then
    Log "[Error] 工作流文件夹为空"
    paramFlag="N"
fi
if [ "X${workflow_name}" == "X" ];then
    Log "[Error] 工作流名称为空"
    paramFlag="N"
fi
if [ "X${paramfile}" == "X" ];then
    Log "[Error] 参数文件为空"
    paramFlag="N"
fi
echo
if [ "X${paramFlag}" == "XN" ];then
    Log "[Error] 参数有误, 请检查..."
    echo
    exit 1
else
    Log "[Info ] 传入参数检查完成"
fi

echo
Log "[Info ] 开始调度工作流执行:"
execFlag="Y"
Log "pmcmd startworkflow -sv ${domain_service} -d ${domain_name} -u ${domain_user} -p ****** -folder ${folder_name} -paramfile ${paramfile} -wait ${workflow_name}"
pmcmd startworkflow -sv ${domain_service} -d ${domain_name} -u ${domain_user} -p ${domain_password} -folder ${folder_name} -paramfile ${paramfile} -wait ${workflow_name}
execRes=$?
if [ ${execRes} -eq 0 ];then
    Log "[Info ] 工作流[${workflow_name}]执行完成"
else
    execFlag="N"
    if [ ${execRes} -eq 1 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 集成服务不可用，或 pmcmd 无法连接到集成服务。 TCP/IP 主机名、端口号或者网络存在问题。"
    elif [ ${execRes} -eq 2 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 任务名称、工作流名称或文件夹名称不存在。"
    elif [ ${execRes} -eq 3 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 启动或运行工作流或任务时出错。"
    elif [ ${execRes} -eq 4 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 使用错误。 您将错误的选项传递到 pmcmd。"
    elif [ ${execRes} -eq 5 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 发生了内部 pmcmd 错误。"
    elif [ ${execRes} -eq 7 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 您使用的用户名或密码无效。"
    elif [ ${execRes} -eq 8 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 您没有相应的权限或特权，无法执行该任务。"
    elif [ ${execRes} -eq 9 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 发送请求时，与集成服务的连接超时。"
    elif [ ${execRes} -eq 12 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 集成服务无法启动恢复，因为会话或工作流已计划、正在等待事件、正在等待、正在初始化、正在中止、正在停止、已禁用或正在运行。"
    elif [ ${execRes} -eq 13 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 用户名环境变量设置为空值。"
    elif [ ${execRes} -eq 14 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 密码环境变量设置为空值。"
    elif [ ${execRes} -eq 15 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 缺少用户名环境变量。"
    elif [ ${execRes} -eq 16 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 缺少密码环境变量。"
    elif [ ${execRes} -eq 17 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 参数文件不存在。"
    elif [ ${execRes} -eq 18 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 集成服务找到参数文件，但没有用于会话参数的初始值，例如 $input 或 $output。"
    elif [ ${execRes} -eq 19 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 集成服务无法恢复会话，因为工作流配置为持续运行。"
    elif [ ${execRes} -eq 20 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 发生存储库错误。 确保存储库服务和数据库正在运行，并且未超过与数据库的连接数限制。"
    elif [ ${execRes} -eq 21 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 集成服务正在关闭，不接受新的请求。"
    elif [ ${execRes} -eq 22 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 集成服务找不到您指定的工作流/会话的唯一实例。 使用文件夹名称或工作流名称再次输入命令。"
    elif [ ${execRes} -eq 23 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 没有可用于请求的数据。"
    elif [ ${execRes} -eq 24 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 内存不足。"
    elif [ ${execRes} -eq 25 ];then
        Log "[Error] 工作流[${workflow_name}]执行失败"
        Log "[Error] 已取消命令。"
    else
        Log "[Error] 工作流[${workflow_name}]执行失败"
    fi
fi

echo
Log "[Info ] 查询工作流日志:"
worklogfile="/tmp/${workflow_name}.getworkflowdetails.tmp"
Log "[Info ] pmcmd getworkflowdetails -sv ${domain_service} -d ${domain_name} -u ${domain_user} -p ****** -f ${folder_name} ${workflow_name}"
pmcmd getworkflowdetails -sv ${domain_service} -d ${domain_name} -u ${domain_user} -p ${domain_password} -f ${folder_name} ${workflow_name} 2>&1|tee ${worklogfile}
if [ $? -ne 0 ];then
    Log "[Info ] 查询工作流[${workflow_name}]日志失败"
else
    if [ "X${execFlag}" == "XN" ];then
        Log "[Info ] 查询session日志:"
        session_name=`grep "Workflow run error message" ${worklogfile}|awk -F'[' '{print $3}'|awk -F']' '{print $1}'`
        if [ "X${session_name}" == "X" ];then
            Log "[Error] 获取失败seesionName失败"
        else
            Log "[Info ] pmcmd getsessionstatistics -sv ${domain_service} -d ${domain_name} -u ${domain_user} -p ****** -f ${folder_name} -w ${workflow_name} ${session_name}"
            pmcmd getsessionstatistics -sv ${domain_service} -d ${domain_name} -u ${domain_user} -p ${domain_password} -f ${folder_name} -w ${workflow_name} ${session_name}
            if [ $? -ne 0 ];then
                Log "[Info ] 查询工作流[${workflow_name}]session[${session_name}]日志失败"
            fi
        fi
        if [ -f ${worklogfile} ];then
            rm ${worklogfile}
        fi
    fi
fi

if [ "X${execFlag}" == "XN" ];then
    Log "[Error] 工作流[${workflow_name}]执行失败"
    exit 2
fi

